pub struct Github { /* private fields */ }Trait Implementations
Sourceimpl Provider for Github
impl Provider for Github
type Error = GithubApiErrorResponse
type Project = GithubProject
fn new( filter: Filter, secret_token: AuthToken, api_url_override: Option<Url>, ) -> Result<Self, Error>
fn filter(&self) -> &Filter
fn secret_token(&self) -> &AuthToken
fn auth_header_key() -> &'static str
fn get_user_projects( &self, user: &User, ) -> Result<Vec<GithubProject>, ApiError<GithubApiErrorResponse>>
fn get_group_projects( &self, group: &Group, ) -> Result<Vec<GithubProject>, ApiError<GithubApiErrorResponse>>
fn get_accessible_projects( &self, ) -> Result<Vec<GithubProject>, ApiError<GithubApiErrorResponse>>
fn get_current_user(&self) -> Result<User, ApiError<GithubApiErrorResponse>>
fn get_own_projects(&self) -> Result<Vec<Self::Project>, ApiError<Self::Error>>
Sourcefn call_list(
&self,
uri: &Url,
accept_header: Option<&str>,
) -> Result<Vec<Self::Project>, ApiError<Self::Error>>
fn call_list( &self, uri: &Url, accept_header: Option<&str>, ) -> Result<Vec<Self::Project>, ApiError<Self::Error>>
Calls the API at specific uri and expects a successful response of
Vec<T> back, or an error response U Read morefn get_repos( &self, worktree_setup: WorktreeSetup, protocol_config: ProtocolConfig, remote_name: Option<RemoteName>, ) -> Result<HashMap<Option<ProjectNamespace>, Vec<Repo>>, Error>